@@ -133,7 +133,7 @@ plotIdiograms(humChr,                     # data.frame of chromosome size (in pa
 
               centromereSize = 0,         # apparent centromere size
               
-              roundness = 10,             # roundness of chr. and marks
+              squareness = 10,             # squareness of chr. and marks
               legend = "inline",          # mark labels next to chr.
               markLabelSize = .5,         # size of legend font
               colorBorderMark = "black",  # force color of border of marks 
@@ -185,7 +185,7 @@ plotIdiograms(dfChrSizeDer,               # data.frame of chromosome size
               chrWidth = 1,               # chromosome width
               karHeight = 9,              # kar. height without space
               centromereSize = 0,         # apparent centromere size
-              roundness = 7,              # roundness of chr. and marks
+              squareness = 7,              # squareness of chr. and marks
 
               markLabelSize = .5,         # size of legend font
               legend = "inline",          # mark labels next to chr.
